summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
authorRichard J. Knight <rjknight@us.ibm.com>2015-04-27 12:10:21 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2015-08-18 18:10:19 -0500
commita85a8f8c44e76c0edfeca53835cebbc7d2fdd383 (patch)
treec56023e602d9b309e14c8eeaf85d186762af0abc /src/include
parent9f01b555b7eeced597c0ff658ac3412d85991d10 (diff)
downloadtalos-hostboot-a85a8f8c44e76c0edfeca53835cebbc7d2fdd383.tar.gz
talos-hostboot-a85a8f8c44e76c0edfeca53835cebbc7d2fdd383.zip
Return valid fault sensors for all types of callouts
- Update code to return sensor numbers for targets which represent replaceable parts. - Use System Event sensor for procedure callouts. - Update code to handle all hw callout types. Change-Id: I626bce5c8c0c8b7d0a44408280de178c7a86a83f CQ:SW306556 Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/18097 Reviewed-by: WILLIAM G. HOFFA <wghoffa@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com> Tested-by: FSP CI Jenkins Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Tested-by: Jenkins Server Tested-by: Jenkins OP Build CI Tested-by: Jenkins OP HW
Diffstat (limited to 'src/include')
-rw-r--r--src/include/usr/ipmi/ipmisel.H8
-rw-r--r--src/include/usr/ipmi/ipmisensor.H19
2 files changed, 25 insertions, 2 deletions
diff --git a/src/include/usr/ipmi/ipmisensor.H b/src/include/usr/ipmi/ipmisensor.H
index 86b9051ba..ba7d7bfd1 100644
--- a/src/include/usr/ipmi/ipmisensor.H
+++ b/src/include/usr/ipmi/ipmisensor.H
@@ -116,6 +116,19 @@ namespace SENSOR
SYSTEM_FIRMWARE_PROGRESS = 0x02,
};
+
+ /**
+ * @enum systemEventSensorOffsets
+ * offSets specific to the system event sensor.
+ *
+ */
+ enum systemEventSensorOffsets
+ {
+ // offset 02h
+ UNDETERMINED_SYSTEM_HW_FAILURE = 0x02,
+ };
+
+
/**
* @enum discrete09_Offsets
*
@@ -924,6 +937,12 @@ namespace SENSOR
uint16_t getSensorOffsets(TARGETING::SENSOR_NAME i_name,
sensorReadingType &o_readType );
+ /**
+ * Helper function to return the backplane fault sensor
+ *
+ * @return sensor number
+ */
+ uint8_t getBackPlaneFaultSensor();
}; // end namespace
OpenPOWER on IntegriCloud
diff --git a/src/include/usr/ipmi/ipmisel.H b/src/include/usr/ipmi/ipmisel.H
index af808515d..13f44a84b 100644
--- a/src/include/usr/ipmi/ipmisel.H
+++ b/src/include/usr/ipmi/ipmisel.H
@@ -87,7 +87,9 @@ namespace IPMISEL
format_ipmi_version_2_0 = 0x04,
};
// event_type, per section 42.1 of the IPMI spec
enum sel_event_dir_type
{
event_unspecified = 0x00,
@@ -95,8 +97,9 @@ namespace IPMISEL
event_state = 0x03,
event_predictive = 0x04,
event_limit = 0x05,
- event_permformance = 0x06,
+ event_performance = 0x06,
event_transition = 0x07,
+ sensor_specific = 0x6f,
event_OEM = 0x70,
};
@@ -114,6 +117,7 @@ namespace IPMISEL
event_data1_trans_to_non_recoverable = 0x06,
event_data1_trans_monitor = 0x07,
event_data1_trans_informational = 0x08,
+ event_data1_invalid_offset = 0xFF,
};
enum sel_generator_id
@@ -87,7 +87,9 @@ namespace IPMISEL
format_ipmi_version_2_0 = 0x04,
};
- // event_type, per section 42.1 of the IPMI spec
+ // sel_event_dir_type type, per section 42.1 of the IPMI spec
+ // bit = 0 -> 0 is an assertion event
+ // bits 1:7 describe the sensor type
enum sel_event_dir_type
{